<?php

/**
*
* Trackback Manager Class for MODx 0.9.5
*
*  Author  : soushi
*  Version : 1.02
*  Date    : 2007/9/10
*
*  License : GPL
*
*/

require_once('tbconfig.php');

class TrackbackMng{

  var $Charset;           // Charset
  var $Theme;             // CSS Theme
  var $TopURI;            // Top URI
  var $Cnf;               // Config data
  var $LogLevel;          // Log Level

  var $TbPageMax = 5;     // Page List Max(x2)

  //opcode
  var $OP_DEFAULT     = 'default';  //default mode
  var $OP_TBLIST      = 'tblist';   //trackback list mode
  var $OP_TBEDIT      = 'tbedit';   //trackback edit mode
  var $OP_TBDETAIL    = 'tbdetail'; //trackback detail mode
  var $OP_CONFIG      = 'config';   //config mode
  var $OP_SAVECONFIG  = 'saveconfig';  //save config mode
  var $OP_DBCREATE    = 'dbcreate';  //save config mode

  //-----------------------------------------------------
  // Class Constructure
  // 
  // $fCharset  : string : text charset
  // $fChunk    : string : Chunk name
  // $fLogLevel : intger : Log level
  // return : none
  //-----------------------------------------------------
  function TrackbackMng($fCharset = "UTF-8",$fChunk='',$fLogLevel=''){
    global $modx;

    $this->Cnf      = new TrackbackConfig($fChunk,$fLogLevel);
    $this->LogLevel = $fLogLevel == '' ? $this->Cnf->L_ERROR : $fLogLevel;
    $this->Charset  = $fCharset;
    $this->TopURI   = $_SERVER["REQUEST_URI"];

    //if(extension_loaded("mbstring")){
    //  $this->mbEnable = true;
    //}

  } 

  //-----------------------------------------------------
  //  Main routine
  //
  // $fOpcode : string : operation code
  //  return  : string : result HTML
  //-----------------------------------------------------
  function Action($fOpcode){
    global $_lang;

    $output = '';
    $info = '';
    $err  = '';
    switch($fOpcode) {
    case $this->OP_TBEDIT: // edit mode
      if( $this->EditTbList() ){
	$info = $_lang['tbm_tbedit_ok'];
      }else{
	$err = $_lang['tbm_tbedit_ok'];
      }

    case $this->OP_TBLIST: // list mode
      $output = $this->ShowHeader().
	$this->ShowTbList($info,$err).
	$this->ShowFooter();
      break;

    case $this->OP_TBDETAIL: // detail mode
      $output = $this->ShowHeader().
	$this->ShowTbDetail().
	$this->ShowFooter();
      break;

    case $this->OP_CONFIG: // config mode
      $output = $this->ShowHeader().
	$this->ShowConfig().
	$this->ShowFooter();
      break;

    case $this->OP_SAVECONFIG: // saveconfig mode
      if( $this->Cnf->SetConfigFromPost()){
	$output = $this->ShowHeader();
	if( $this->Cnf->SaveConfigToChunk()){
	  $output .= $this->ShowMenu();
	}else{
	  $output .= 'fail!';
	}
	$output .= $this->ShowFooter();
		
      }else{
      $output = $this->ShowHeader().
	$this->ShowConfig('',$this->Cnf->ErrMsg).
	$this->ShowFooter();
      }
      break;

    case $this->OP_DBCREATE: // database initialisation
      if( $this->Cnf->DBInit() ){
	$msg= $_lang['tbm_tb_create_ok'];
      }else{
	$msg= $this->Cnf->ErrMsg;
      }
      $output = $this->ShowHeader().
	$this->ShowMenu($msg).
	$this->ShowFooter();
      break;
	
    default: // display manu page
      $output = $this->ShowHeader().
	$this->ShowMenu().
	$this->ShowFooter();
      break;
      
    }

    return $output;
  }

  //-----------------------------------------------------
  //  Set theme
  //
  // $fTheme : string : css theme path
  //  return : none
  //-----------------------------------------------------
  function SetTheme($fTheme){
    $this->Theme = $fTheme;
  }

  //-----------------------------------------------------
  //  Show Header
  //
  //  return : string : header HTML
  //-----------------------------------------------------
  function ShowHeader(){
    global $_lang;

    $output =  
      '<html>'."\n".
      '<head>'."\n".
      '  <link rel="stylesheet" type="text/css" href="media/style'.$this->Theme.'/style.css" />'."\n".
      '  <link rel="stylesheet" type="text/css" href="media/style'.$this->Theme.'/coolButtons2.css" />'."\n".
      '  <script language="JavaScript" type="text/javascript">'."\n".
      'function postForm(opcode){'."\n".
      '  document.module.opcode.value=opcode;'."\n".
      '  document.module.submit();'."\n".
      '}'."\n".
      '  </script>'."\n".
      '  <style TYPE="text/css">'."\n".
      '    <!--'."\n".
      '        .sectionBody table tr,.subTitle table tr { font-size: 68.75%; }'."\n".
      '    -->'."\n".
      '  </style>'."\n".
      '</head>'."\n".
      '<body>'."\n";

    return $output;
  }

  //-----------------------------------------------------
  //  Show Footer
  //
  //  return : string : footer HTML
  //-----------------------------------------------------
  function ShowFooter(){

    $output = 
      '</body>'."\n".
      '</html>'."\n";

    return $output;
  }

  //-----------------------------------------------------
  //  Show Menu
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowMenu($fInfoMsg='',$fErrMsg=''){
    //global $modx;
    global $_lang;

    $infoMsg=$this->MakeInfo($fInfoMsg,'info');
    $errMsg =$this->MakeInfo($fErrMsg,'err');

    $output = <<<_
<script language="JavaScript" type="text/javascript">
  function postDBCreate(opcode){
    if( confirm("${_lang['tbm_btn_go_dbcreate_check1']}") 
     && confirm("${_lang['tbm_btn_go_dbcreate_check2']}")){
      document.module.opcode.value=opcode;
      document.module.submit();
    }
  }
</script>
<div class="subTitle">
  <span class="right">
    <img src="media/images/_tx_.gif" width="1" height="5"><br />
   ${_lang['tbm_title_top']}
  </span>
  <table cellpadding="0" cellspacing="0" class="actionButtons">
    <tr>
      <td id="Button5">
        <a href="#" onclick="document.location.href='index.php?a=106';"><img src="media/style/MODxLight/images/icons/cancel.gif" />${_lang['tbm_btn_cancel']}</a>
      </td>
    </tr>
  </table>
</div>
{$infoMsg}
{$errMsg}
<form name="module" method="post">
  <input name="opcode" type="hidden" value="" />
  <div class="sectionHeader">
    <img src="media/images/misc/dot.gif" alt="." />&nbsp;${_lang['tbm_title_config']}
  </div>
  <div class="sectionBody">
    <table cellpadding="0" cellspacing="0" class="actionButtons">
      <tr>
        <td id="Button1">
          <a href="#" onclick="postForm('{$this->OP_TBLIST}');">
            <img src="media/style/MODxLight/images/icons/save.gif" align="absmiddle">{$_lang['tbm_btn_go_tblist']}
          </a>
        </td>
      </tr>

      <tr>
        <td colspan="1"><div class='split'></div></td>
      </tr>

      <tr>
        <td style="padding-left:2em;">{$_lang['tbm_btn_go_tblist_detail']}</td>
      </tr>

      <tr>
        <td colspan="2"><div class='split'></div></td>
      </tr>

      <tr>
        <td id="Button1">
          <a href="#" onclick="postForm('{$this->OP_CONFIG}');">
            <img src="media/style/MODxLight/images/icons/save.gif" align="absmiddle">{$_lang['tbm_btn_go_config']}
          </a>
        </td>
      </tr>

      <tr>
        <td colspan="1"><div class='split'></div></td>
      </tr>

      <tr>
        <td style="padding-left:2em;">{$_lang['tbm_btn_go_config_detail']}</td>
      </tr>

      <tr>
        <td colspan="1"><div class='split'></div></td>
      </tr>
      <tr>
        <td colspan="1">&nbsp;</td>
      </tr>
      <tr>
        <td colspan="1">&nbsp;</td>
      </tr>


      <tr>
        <td id="Button1">
          <a href="#" onclick="postDBCreate('{$this->OP_DBCREATE}');">
            <img src="media/style/MODxLight/images/icons/save.gif" align="absmiddle">{$_lang['tbm_btn_go_dbcreate']}
          </a>
        </td>
      </tr>

      <tr>
        <td colspan="1"><div class='split'></div></td>
      </tr>

      <tr>
        <td style="padding-left:2em;">{$_lang['tbm_btn_go_dbcreate_detail']}</td>
      </tr>


    </table>

    <br />
  </div>
</form>
_;

    return $output;

  } 

  //-----------------------------------------------------
  //  Edit Trackback Edit
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function EditTbList(){
    global $modx;
    global $_lang;

    if( isset($_POST['DView']) && is_array($_POST['DView'])){
      $dView = $_POST['DView'];
    }
    if( isset($_POST['CheckView']) && is_array($_POST['CheckView'])){
      $cView = $_POST['CheckView'];
    }
    if( isset($_POST['CheckDele']) && is_array($_POST['CheckDele'])){
      $cDele = $_POST['CheckDele'];
    }

    foreach( $cView as $key =>$val ){
      if(! is_numeric($val)){
	unset($cView[$key]);
	continue;
      }
      $key2 = array_search($val,$dView);
      if( $key2 !== false){
	unset($dView[$key2]);
	unset($cView[$key]);
      }
    }
    foreach( $dView as $key =>$val ){
      if(! is_numeric($val)){unset($dView[$key]);}
    }

    //enable view
    $fields = 'status = ' . $this->Cnf->ST_VIEW . ' | status';
    $where = '';
    foreach( $cView as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->update($fields,
				   $this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    //disable view
    $fields = 'status = ~' . $this->Cnf->ST_VIEW . ' & status';
    $where = '';
    foreach( $dView as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->update($fields,
				   $this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    //delete trackback
    $where = '';
    foreach( $cDele as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->delete($this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    return true;

  }

  //-----------------------------------------------------
  //  Show Trackback Edit
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowTbList($fInfoMsg='',$fErrMsg=''){
    global $modx;
    global $_lang;

    $infoMsg=$this->MakeInfo($fInfoMsg,'info');
    $errMsg =$this->MakeInfo($fErrMsg,'err');

    // make tblist line
    $tbLineHTML='';
    if( isset($_POST['tbLine'])  && is_numeric($_POST['tbLine']) && $_POST['tbLine'] >= 0 ){
      $tbLine = $_POST['tbLine'];
    }else{
      $tbLine = 20;
    }
    foreach(array(10,20,50,100,0) as $val){
      $tmpSelect = $tbLine ==  $val ? ' selected=" selected"' : '';
      $tmpVal = $val == 0 ? $_lang['tbm_tblist_lineall'] : $val;
      $tbLineHTML .= '<option value="'.$val.'"'.$tmpSelect.'>'.$tmpVal.'</option>' . "\n";
    }
    $tbLineHTML = '<select name="tbLine" class="inputBox" onchange="postForm(\''.$this->OP_TBLIST.'\');">'.
      $tbLineHTML.'</select>';

    //make page list
    if( $tbLine == 0 ){
      $tbPageHTML = '';
      $tbPage = 1;
    }else{
      if( isset($_POST['tbPage'])  && is_numeric($_POST['tbPage']) && $_POST['tbPage'] > 0 ){
	$tbPage = $_POST['tbPage'];
      }else{
	$tbPage = 1;
      }
      if(! $rs = $modx->db->select("count(*) as cnt",
				   $this->Cnf->Table)){
	return $_lang['tbm_fail_query'];
      }
      $row= $modx->db->getRow($rs);
      $cnt=$row['cnt'];
      $tbAllPage = (int)((($cnt - 1)/ $tbLine)+1);
      $tbPage > $tbAllPage && $tbPage = $tbAllPage;
      if( $tbAllPage != 0 ){
	$tbLHTML = '';
	$tbRHTML = '';
	$tbLNum = $tbPage;
	$tbRNum = $tbPage;
	for( $i = 0 ; $i < $this->TbPageMax ; $i++){
	  $tbLNum = $tbLNum - 1;
	  if( $tbLNum >= 1 ){
	    $tbLHTML = '<a href="#" onclick="changeTbPage('.$tbLNum.');postForm(\''.$this->OP_TBLIST.'\');">'.
	      $tbLNum.'</a>'. '&nbsp;'."\n". $tbLHTML ;
	  }
	  $tbRNum = $tbRNum + 1;
	  if( $tbRNum <= $tbAllPage ){
	    $tbRHTML .= '&nbsp;'.
	      '<a href="#" onclick="changeTbPage('.$tbRNum.');postForm(\''.$this->OP_TBLIST.'\');">'.
	      $tbRNum.'</a>'."\n";
	  }
	}
	$tbLNum > 1 && $tbLHTML = '...' . $tbLHTML;
	$tbRNum < $tbAllPage && $tbRHTML .= '...';
	$tbPageHTML = '<div style="text-align:right">'.
	  $tbLHTML.$tbPage."\n".$tbRHTML.
	  '('. $_lang['tbm_tblist_total'] . $cnt.')'.
	  '</div>' . "\n";
      }
    }

    //make tb list(header) and set Sort
    $tbListHead = '';
    if( isset($_POST['tbSort'])  && is_numeric($_POST['tbSort']) && $_POST['tbSort'] > 0 ){
      $tbSort = $_POST['tbSort'];
    }else{
      $tbSort = 4; //4 = create date
    }
    if( isset($_POST['tbDesc']) && $_POST['tbDesc'] == 0){
      $tbDesc = 0;
    }else{
      $tbDesc = 1;
    }
    for( $i=1 ; $i<8 ; $i++){
      $rowText = $_lang['tbm_tblist_row'.$i];
      if( $i != 5 && $i != 7 ){
	if( $i != $tbSort){
	  $rowJS='onclick="changeTbSort('.$i.');postForm(\''.$this->OP_TBLIST.'\');"';
	}else{
	  $rowText .= $_lang['tbm_tblist_desc'.$tbDesc];
	  $rowJS='onclick="changeTbDesc('.$tbDesc.');postForm(\''.$this->OP_TBLIST.'\');"';
	}
      }else{
	$rowJS='';
      }

      $tbListHead .= '<td  class="gridHeader" align="center" style="cursor:pointer;" '.$rowJS.'>'.$rowText.'</a></td>'."\n";
    }
    $tbListHead = '<tr>'.$tbListHead.'</tr>';

    //make tb list
    if( $tbLine != 0 && $tbPage != 0 ){
      $topTb = ($tbPage - 1) * $tbLine;
      $limit = $topTb.','.$tbLine;
    }else{
      $limit = '';
    }
    switch($tbSort){
    case 1:
      $order = 'parent_id';
      break;
    case 2:
      $order = 'title';
      break;
    case 3:
      $order = 'blog_name';
      break;
    case 6:
      $order = 'status';
      break;
    default:
      $order = 'date';
    }
    $desc = $tbDesc == 1 ? 'desc' : '';
    if(! $rs = $modx->db->select("id,parent_id,url,title,blog_name, date,status",
				 $this->Cnf->Table,
				 '',
				 "$order $desc",
				 $limit)){

      return $_lang['tbm_fail_query'];
    }
    $i=0;
    $swapCSS[0] = 'gridItem';
    $swapCSS[1] = 'gridAltItem';
    $tbList = '';
    $tbListHide = '';
    while ($row= $modx->db->getRow($rs)) {

      $date = strftime("%Y/%m/%d %T",$row['date']);
      $row['view'] = ($row['status'] & $this->Cnf->ST_VIEW) > 0 ? true:false;
      $row['new'] = ($row['status'] & $this->Cnf->ST_NEW) > 0 ? true:false;
      $tbNew = $row['new'] == true ? '('.$_lang['tbm_tblist_new'].')' : '';

      if( $row['view'] == true ){
	$tbListHide .= '<input name="DView[]" type="hidden" value="'.$row['id'].'" />' . "\n";
      }

      $tbList .=<<<_
<tr>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="{$modx->makeUrl($row['parent_id'],'','','full')}" target="_blank">
        {$row['parent_id']}
    </a>
    <span style="font-size:90%">{$tbNew}</span>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="{$row['url']}" target="_blank">
	{$row['title']}
    </a>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">{$row['blog_name']}</td>
  <td  class="{$swapCSS[$i]}" align="center">{$date}</td>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="#" onclick="postFormDetail('{$this->OP_TBDETAIL}',{$row['id']});">
      {$_lang['tbm_tblist_detail']}
    </a>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    {$this->MakeCheckBox('CheckView[]',$row['id'],$row['view'])}
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    {$this->MakeCheckBox('CheckDele[]',$row['id'],false)}
  </td>

</tr>

_;
      $i = 1 - $i;
    }
    $tbList == '' && $tbList = '<tr><td colspan="7" class="gridItem" align="center">'.$_lang['tbm_tblist_no_list'].'</td></tr>';

    $output = <<<_
<script language="JavaScript" type="text/javascript">
  function changeTbPage(num){
      document.module.tbPage.value=num;
      return true;
  }
  function changeTbSort(num){
      document.module.tbSort.value=num;
      return true;
  }
  function changeTbDesc(num){
      document.module.tbDesc.value=1-num;
      return true;
  }
  function postFormDelCk(opcode){
    flag=0;
    for (i=0; i<document.module.elements['CheckDele[]'].length; i++){
      if( document.module.elements['CheckDele[]'][i].checked ){
	flag=1;
      }
    }
    if( flag==0 || (flag== 1 && confirm("{$_lang['tbm_tblist_del_check']}")) ){
      document.module.opcode.value=opcode;
      document.module.submit();
    }
  }
  function postFormDetail(opcode,num){
      document.module.tbDetail.value=num;
      document.module.opcode.value=opcode;
      document.module.submit();
  }
</script>
<div class="subTitle">
  <span class="right">
    <img src="media/images/_tx_.gif" width="1" height="5"><br />
    ${_lang['tbm_title_tblist']}
  </span>
  <table cellpadding="0" cellspacing="0" class="actionButtons">
    <tr>
      <td id="Button1">
      <a href="#" onclick="postFormDelCk('{$this->OP_TBEDIT}');"><img src="media/style/MODxLight/images/icons/save.gif" />${_lang['tbm_btn_edit']}</a>
      </td>
      <td id="Button5">
        <a href="#" onclick="document.location.href='{$this->TopURI}';"><img src="media/style/MODxLight/images/icons/cancel.gif" />${_lang['tbm_btn_cancel']}</a>
      </td>
    </tr>
  </table>
</div>
{$infoMsg}
{$errMsg}
<form name="module" method="post">
  <input name="opcode" type="hidden" value="" />
  <input name="tbPage" type="hidden" value="{$tbPage}" />
  <input name="tbSort" type="hidden" value="{$tbSort}" />
  <input name="tbDesc" type="hidden" value="{$tbDesc}" />
  <input name="tbDetail" type="hidden" value="" />
  {$tbListHide}
  <div class="sectionHeader">
    <img src="media/images/misc/dot.gif" alt="." />&nbsp;
      {$_lang['tbm_title_tblist']}&nbsp;&nbsp;:&nbsp;&nbsp;{$_lang['tbm_tblist_line']}{$tbLineHTML}
  </div>
  <div class="sectionBody">
  {$tbPageHTML}
  <table class='grid'  cellpadding='1' cellspacing='1'>
    {$tbListHead}
    {$tbList}
  </table>
  </div>
</form>

_;
    return $output;

  } 

  //-----------------------------------------------------
  //  Show Trackback Detail
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowTbDetail($fInfoMsg='',$fErrMsg=''){
    global $modx;
    global $_lang;

    $infoMsg=$this->MakeInfo($fInfoMsg,'info');
    $errMsg =$this->MakeInfo($fErrMsg,'err');

    if(!( isset($_POST['tbDetail']) && 
	is_numeric($_POST['tbDetail']) &
	  $_POST['tbDetail'] > 0)){
      return $_lang['tbm_detail_no_id'];
    }
    $tbDetail = $_POST['tbDetail'];

    //drop new flag
    if(! $rs = $modx->db->update('status = ~' . $this->Cnf->ST_NEW . ' & status',
				 $this->Cnf->Table,
				 "id = $tbDetail")){
      return $_lang['tbm_fail_query'];
    }

    if(! $rs = $modx->db->select('*',
				 $this->Cnf->Table,
				 "id = $tbDetail")){
      return $_lang['tbm_fail_query'];
    }
    $row= $modx->db->getRow($rs);

    $row['view'] = ($row['status'] & $this->Cnf->ST_VIEW) > 0 ? true:false;
    $row['new'] = ($row['status'] & $this->Cnf->ST_NEW) > 0 ? true:false;
    $excerpt = str_replace("\n","<br />\n",$row['excerpt']);
    $date = strftime("%Y/%m/%d %T",$row['date']);
    $view = $row['view'] == true ? $_lang['tbm_detail_view_ok'] : $_lang['tbm_detail_view_ng'];

    //other hidden data
    if( isset($_POST['tbPage'])  && is_numeric($_POST['tbPage']) && $_POST['tbPage'] >= 0 ){
      $tbPage = $_POST['tbPage'];
    }
    if( isset($_POST['tbSort'])  && is_numeric($_POST['tbSort']) && $_POST['tbSort'] > 0 ){
      $tbSort = $_POST['tbSort'];
    }
    if( isset($_POST['tbDesc']) && $_POST['tbDesc'] == 0){
      $tbDesc = 0;
    }else{
      $tbDesc = 1;
    }
    if( isset($_POST['tbLine'])  && is_numeric($_POST['tbLine']) && $_POST['tbLine'] >= 0 ){
      $tbLine = $_POST['tbLine'];
    }

    $output = <<<_
<div class="subTitle">
  <span class="right">
    <img src="media/images/_tx_.gif" width="1" height="5"><br />
    ${_lang['tbm_title_detail']}
  </span>
  <table cellpadding="0" cellspacing="0" class="actionButtons">
    <tr>
      <td id="Button1">
      <a href="#" onclick="postForm('{$this->OP_TBLIST}');"><img src="media/style/MODxLight/images/icons/cancel.gif" />${_lang['tbm_btn_back']}</a>
      </td>
    </tr>
  </table>
</div>
{$infoMsg}
{$errMsg}
<form name="module" method="post">
  <input name="opcode" type="hidden" value="" />
  <input name="tbPage" type="hidden" value="{$tbPage}" />
  <input name="tbSort" type="hidden" value="{$tbSort}" />
  <input name="tbDesc" type="hidden" value="{$tbDesc}" />
  <input name="tbLine" type="hidden" value="{$tbLine}" />

  <div class="sectionHeader">
    <img src="media/images/misc/dot.gif" alt="." />&nbsp;
      {$_lang['tbm_title_detail']}
  </div>
  <div class="sectionBody">
  <table border="0" cellspacing="0" cellpadding="3">

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row1']}:</td>
      <td >
        <a href="{$modx->makeUrl($row['parent_id'],'','','full')}" target="_blank">
	  {$row['parent_id']}
        </a>
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row2']}:</td>
      <td >
        <a href="{$row['domain']}" target="_blank">
	  {$row['domain']}
        </a>
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row3']}:</td>
      <td >
       {$row['remoteip']}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row4']}:</td>
      <td >
        <a href="{$row['url']}" target="_blank">
         {$row['url']}
        </a>
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row5']}:</td>
      <td >
       {$row['blog_name']}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row6']}:</td>
      <td >
       {$row['title']}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row7']}:</td>
      <td >
       {$excerpt}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row8']}:</td>
      <td >
       {$date}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">${_lang['tbm_detail_row9']}:</td>
      <td >
       {$view}
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

  </table>

  </div>
</form>

_;
    return $output;


  }

  //-----------------------------------------------------
  //  Show Config
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowConfig($fInfoMsg='',$fErrMsg=''){
    //global $modx;
    global $_lang;

    $infoMsg=$this->MakeInfo($fInfoMsg,'info');
    $errMsg =$this->MakeInfo($fErrMsg,'err');

    $output = <<<_
<div class="subTitle">
  <span class="right">
    <img src="media/images/_tx_.gif" width="1" height="5"><br />
    ${_lang['tbm_title_top']}
  </span>
  <table cellpadding="0" cellspacing="0" class="actionButtons">
    <tr>
      <td id="Button1">
      <a href="#" onclick="postForm('{$this->OP_SAVECONFIG}');"><img src="media/style/MODxLight/images/icons/save.gif" />${_lang['tbm_btn_save']}</a>
      </td>
      <td id="Button5">
        <a href="#" onclick="document.location.href='{$this->TopURI}';"><img src="media/style/MODxLight/images/icons/cancel.gif" />${_lang['tbm_btn_cancel']}</a>
      </td>
    </tr>
  </table>
</div>
{$infoMsg}
{$errMsg}
<form name="module" method="post">
  <input name="opcode" type="hidden" value="" />
  <div class="sectionHeader">
    <img src="media/images/misc/dot.gif" alt="." />&nbsp;
    {$_lang['tbm_title_config']}
  </div>
  <div class="sectionBody">
  <table border="0" cellspacing="0" cellpadding="3">
    <tr>
      <td nowrap class="warning">${_lang['tbm_conf_EnableSendAlert']}:</td>
      <td >
        {$this->MakeRadioYesNo('EnableSendAlert',$this->Cnf->GetValue('EnableSendAlert'))}<br />
      {$_lang['tbm_conf_detail_EnableSendAlert']}:<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_SendAlertUser']}:</td>
      <td >
       {$this->MakeTextbox('SendAlertUser',$this->Cnf->GetValue('SendAlertUser'),30)}<br />
      ${_lang['tbm_conf_detail_SendAlertUser']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_ReceiveDocID']}:</td>
      <td >
       {$this->MakeTextbox('ReceiveDocID',$this->Cnf->GetValue('ReceiveDocID'),3,20)}<br />
       {$_lang['tbm_conf_detail_ReceiveDocID']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_DocAuthor']}:</td>
      <td >
        {$this->MakeTextbox('DocAuthor',$this->Cnf->GetValue('DocAuthor'),30)}<br />
        {$_lang['tbm_conf_detail_DocAuthor']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_OverwriteDocAuthor']}:</td>
      <td >
        {$this->MakeRadioYesNo('OverwriteDocAuthor',$this->Cnf->GetValue('OverwriteDocAuthor'))}<br />
        {$_lang['tbm_conf_detail_OverwriteDocAuthor']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_AllowDocID_Recv']}:</td>
      <td >
        {$this->MakeTextbox('AllowDocID_Recv',$this->Cnf->GetValue('AllowDocID_Recv'),30)}<br />
        {$_lang['tbm_conf_detail_AllowDocID_Recv']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_AllowDocID_Send']}:</td>
      <td >
        {$this->MakeTextbox('AllowDocID_Send',$this->Cnf->GetValue('AllowDocID_Send'),30)}<br />
        {$_lang['tbm_conf_detail_AllowDocID_Send']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_AllowDocID_View']}:</td>
      <td >
        {$this->MakeTextbox('AllowDocID_View',$this->Cnf->GetValue('AllowDocID_View'),30)}<br />
        {$_lang['tbm_conf_detail_AllowDocID_View']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_EnableNowOpen']}:</td>
      <td >
        {$this->MakeRadioYesNo('EnableNowOpen',$this->Cnf->GetValue('EnableNowOpen'))}<br />
        {$_lang['tbm_conf_detail_EnableNowOpen']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_NowOpenExceptOpenDomain']}:</td>
      <td >
        {$this->MakeRadioYesNo('NowOpenExceptOpenDomain',$this->Cnf->GetValue('NowOpenExceptOpenDomain'))}<br />
        {$_lang['tbm_conf_detail_NowOpenExceptOpenDomain']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_NowOpenExceptDocID']}:</td>
      <td >
        {$this->MakeTextbox('NowOpenExceptDocID',$this->Cnf->GetValue('NowOpenExceptDocID'),30)}<br />
        {$_lang['tbm_conf_detail_NowOpenExceptDocID']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_DenyHideTb']}:</td>
      <td >
        {$this->MakeRadioYesNo('DenyHideTb',$this->Cnf->GetValue('DenyHideTb'))}<br />
        {$_lang['tbm_conf_detail_DenyHideTb']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_DenyDoubleTb']}:</td>
      <td >
        {$this->MakeRadioYesNo('DenyDoubleTb',$this->Cnf->GetValue('DenyDoubleTb'))}<br />
        {$_lang['tbm_conf_detail_DenyDoubleTb']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_DenyThisTb']}:</td>
      <td >
	{$this->MakeTextbox('DenyThisTb',$this->Cnf->GetValue('DenyThisTb'),255,100)}<br />
        {$_lang['tbm_conf_detail_DenyThisTb']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_CheckOnSendPingFromTV']}:</td>
      <td >
        {$this->MakeRadioYesNo('CheckOnSendPingFromTV',$this->Cnf->GetValue('CheckOnSendPingFromTV'))}<br />
        {$_lang['tbm_conf_detail_CheckOnSendPingFromTV']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_CheckOnSendPingAutomatic']}:</td>
      <td >
        {$this->MakeRadioYesNo('CheckOnSendPingAutomatic',$this->Cnf->GetValue('CheckOnSendPingAutomatic'))}<br />
        {$_lang['tbm_conf_detail_CheckOnSendPingAutomatic']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_ViewTpl']}:</td>
      <td >
        {$this->MakeTextbox('ViewTpl',$this->Cnf->GetValue('ViewTpl'),20)}<br />
        {$_lang['tbm_conf_detail_ViewTpl']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_ViewTplTbList']}:</td>
      <td >
        {$this->MakeTextbox('ViewTplTbList',$this->Cnf->GetValue('ViewTplTbList'),20)}<br />
        {$_lang['tbm_conf_detail_ViewTplTbList']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

    <tr>
      <td nowrap class="warning">{$_lang['tbm_conf_EmptyText']}:</td>
      <td >
        {$this->MakeTextbox('EmptyText',$this->Cnf->GetValue('EmptyText'),20)}<br />
      {$_lang['tbm_conf_detail_EmptyText']}<br />
      </td>
    </tr>

    <tr>
      <td colspan="2"><div class='split'></div></td>
    </tr>

  </table>

  </div>
</form>

_;
    return $output;

  } 

  //-----------------------------------------------------
  //  Make Information Table
  //
  //  $fMsg  : string : information/error message
  //  $fType : string : Message Type
  //  return : string : menu HTML  *notine* "\n" -> "<br />\n"
  //-----------------------------------------------------
  function MakeInfo($fMsg='',$fType=''){
    global $_lang;

    if( $fType == 'info'){
      $title = $_lang['tbm_title_info'];
    }else{
      $title = $_lang['tbm_title_error'];
    }

    $output = '';
    if( $fMsg != '' ){
      $fMsg = str_replace("\n","<br />\n",$fMsg);
      $output = 
	'<div class="sectionHeader">'."\n".
	'<img src="media/images/misc/dot.gif" alt="." />&nbsp;'.$title."\n".
	'</div>'."\n".
	'<div class="sectionBody">'."\n".
	$fMsg.
	'</div>'."\n";
    }

    return $output;
  }

  //-----------------------------------------------------
  //  Make radio button(Yes/No)
  //
  //  $fName   : string  : HTML tag name
  //  $fStatus : bool    : Default check
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeRadioYesNo($fName,$fStatus){
    global $_lang;

    if( $fStatus == true ){
      $chkYes = ' checked';
      $chkNo  = ' ';
    }else{
      $chkYes = '';
      $chkNo  = ' checked';
    }
    $output =
      '<input type="radio" name="'.$fName.'" value="1"'.$chkYes.'>'.$_lang['yes'].
      '<input type="radio" name="'.$fName.'" value="0"'.$chkNo.'>'.$_lang['no']."\n";

    return $output;
  }

  //-----------------------------------------------------
  //  Make Checkbox(Single)
  //
  //  $fName   : string  : name option
  //  $fVal    : string  : value option
  //  $fStatus : bool    : Default check
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeCheckBox($fName,$fVal,$fStatus){
    global $_lang;

    $chk = $fStatus == true ? ' checked' : '';
    $output = '<input type="checkbox" name="'.$fName.'" value="'.$fVal.'"'.$chk.'>';

    return $output;
  }

  //-----------------------------------------------------
  //  Make Textbox
  //
  //  $fName   : string         : HTML tag name
  //  $fValue  : string/integer : Default data
  //  $fLen    : integer        : Text Length(default:20)
  //  $fSize   : integer        : Text Area Size(default:$fLen)
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeTextbox($fName,$fValue,$fLen=20,$fSize=0){

    $fLen = is_numeric($fLen) ? $fLen : 20;
    if( $fSize == 0 || ! is_numeric($fSize)){$fSize=$fLen;}

    $output = '<input type="text" name="'.$fName.'" value="'.$fValue.'" size="'.$fSize.'" maxlength="'.$fLen.'"><br />'."\n";

    return $output;
  }

}
?>
